@@ -2,7 +2,7 @@ require 'spec_helper'
 
 on_supported_os.reject { |_, f| f[:os]['family'] == 'Solaris' }.each do |os, f|
   describe 'ntp' do
-    let(:facts) { { is_virtual: 'false' } }
+    let(:facts) { { is_virtual: false } }
 
     context "on #{os}" do
       let(:facts) do
@@ -274,7 +274,7 @@ on_supported_os.reject { |_, f| f[:os]['family'] == 'Solaris' }.each do |os, f|
           end
         end
         describe 'with parameter disable_monitor' do
-          context 'default' do
+          context 'when default' do
             let(:params) do
               {
               }
@@ -308,7 +308,7 @@ on_supported_os.reject { |_, f| f[:os]['family'] == 'Solaris' }.each do |os, f|
           end
         end
         describe 'with parameter enable_mode7' do
-          context 'default' do
+          context 'when default' do
             let(:params) do
               {
               }
@@ -438,6 +438,44 @@ on_supported_os.reject { |_, f| f[:os]['family'] == 'Solaris' }.each do |os, f|
             }
           end
         end
+
+        describe 'slewalways' do
+          context 'when absent' do
+            if f[:kernel] == 'AIX'
+              it 'on AIX does contain "slewalways no"' do
+                is_expected.to contain_file('/etc/ntp.conf').with_content(%r{^slewalways no})
+              end
+            else
+              it 'on non-AIX does not contain a slewalways' do
+                is_expected.to contain_file('/etc/ntp.conf').without_content(%r{^slewalways})
+              end
+            end
+          end
+
+          context 'when "no"' do
+            let(:params) do
+              {
+                slewalways: 'no',
+              }
+            end
+
+            it 'does contain "slewalways no"' do
+              is_expected.to contain_file('/etc/ntp.conf').with_content(%r{^slewalways no})
+            end
+          end
+
+          context 'when "yes"' do
+            let(:params) do
+              {
+                slewalways: 'yes',
+              }
+            end
+
+            it 'does contain "slewalways yes"' do
+              is_expected.to contain_file('/etc/ntp.conf').with_content(%r{^slewalways yes})
+            end
+          end
+        end
       end
 
       describe 'ntp::install' do
@@ -835,7 +873,7 @@ on_supported_os.reject { |_, f| f[:os]['family'] == 'Solaris' }.each do |os, f|
           end
         end
 
-        context 'set' do
+        context 'when set' do
           let(:params) do
             {
               pool: %w[foo bar],
@@ -864,7 +902,7 @@ on_supported_os.reject { |_, f| f[:os]['family'] == 'Solaris' }.each do |os, f|
           end
         end
 
-        context 'set' do
+        context 'when set' do
           let(:params) do
             {
               peers: %w[foo bar],
@@ -882,7 +920,7 @@ on_supported_os.reject { |_, f| f[:os]['family'] == 'Solaris' }.each do |os, f|
 
       describe 'for virtual machines' do
         let :facts do
-          super().merge(is_virtual: 'true')
+          super().merge(is_virtual: true)
         end
 
         it 'does not use local clock as a time source' do
@@ -896,7 +934,7 @@ on_supported_os.reject { |_, f| f[:os]['family'] == 'Solaris' }.each do |os, f|
 
       describe 'for physical machines' do
         let :facts do
-          super().merge(is_virtual: 'false')
+          super().merge(is_virtual: false)
         end
 
         it 'disallows large clock skews' do
